/*! Select2 4.1.0-rc.0 | https://github.com/select2/select2/blob/master/LICENSE.md */
var dalLoadLanguage=function(n){var e;(e=n&&n.fn&&n.fn.select2&&n.fn.select2.amd?n.fn.select2.amd:e).define("select2/i18n/hr",[],function(){function e(n){var e=" "+n+" znak";return n%10<5&&0<n%10&&(n%100<5||19<n%100)?1<n%10&&(e+="a"):e+="ova",e}return{errorLoading:function(){return"Preuzimanje nije uspjelo."},inputTooLong:function(n){return"Unesite "+e(n.input.length-n.maximum)},inputTooShort:function(n){return"Unesite još "+e(n.minimum-n.input.length)},loadingMore:function(){return"Učitavanje rezultata…"},maximumSelected:function(n){return"Maksimalan broj odabranih stavki je "+n.maximum},noResults:function(){return"Nema rezultata"},searching:function(){return"Pretraga…"},removeAllItems:function(){return"Ukloni sve stavke"}}}),e.define,e.require},event=new CustomEvent("dal-language-loaded",{lang:"hr"});document.dispatchEvent(event);