/*! Select2 4.1.0-rc.0 | https://github.com/select2/select2/blob/master/LICENSE.md */
var dalLoadLanguage=function(n){var e;(e=n&&n.fn&&n.fn.select2&&n.fn.select2.amd?n.fn.select2.amd:e).define("select2/i18n/bn",[],function(){return{errorLoading:function(){return"ফলাফলগুলি লোড করা যায়নি।"},inputTooLong:function(n){n=n.input.length-n.maximum;return 1!=n?"অনুগ্রহ করে "+n+" টি অক্ষর মুছে দিন।":"অনুগ্রহ করে "+n+" টি অক্ষর মুছে দিন।"},inputTooShort:function(n){return n.minimum-n.input.length+" টি অক্ষর অথবা অধিক অক্ষর লিখুন।"},loadingMore:function(){return"আরো ফলাফল লোড হচ্ছে ..."},maximumSelected:function(n){var e=n.maximum+" টি আইটেম নির্বাচন করতে পারবেন।";return e=1!=n.maximum?n.maximum+" টি আইটেম নির্বাচন করতে পারবেন।":e},noResults:function(){return"কোন ফলাফল পাওয়া যায়নি।"},searching:function(){return"অনুসন্ধান করা হচ্ছে ..."}}}),e.define,e.require},event=new CustomEvent("dal-language-loaded",{lang:"bn"});document.dispatchEvent(event);